<?php
/**
 * graphique1.php
 *
 * Ce fichier permet de générer un graphique
 *
 * PHP versions 4 and 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   choixMoteurs
 * @package    choixMoteurs
 * @author     David SALLE <david.salle@ac-poitiers.fr>
 * @author     Jean-Jacques MAUPETIT <j-j.maupetit@numericable.fr> 
 * @copyright  1997-2005 The PHP Group
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    v1.0
 * @link       http://sandiris.free.fr/moteurs
 * @see        NetOther, Net_Sample::Net_Sample()
 * @since      File available since Release 0.1
 * @deprecated No
 */


	// Demarrage des sessions
	session_start();

	// Includes pour pouvoir utiliser la librairie JPGRAPH
	include ("jpgraph/src/jpgraph.php");
	include ("jpgraph/src/jpgraph_line.php");
	
	// Recuperation des valeurs contenues dans les cookies
	$couple = $_SESSION["couple"];
	$vitesse = $_SESSION["vitesse"];
	$tension = $_SESSION["tension"];
	$courant = $_SESSION["courant"];
	$puissance = $_SESSION["puissance"];
		
	$reference = $_SESSION["reference"];
	$tensionnominale = $_SESSION["tensionnominale"];
	$puissancemax = $_SESSION["puissancemax"];
	$resistance = $_SESSION["resistance"];
	$courantavide = $_SESSION["courantavide"];
	$vitesseavide = $_SESSION["vitesseavide"];
	$coupledemarrage = $_SESSION["coupledemarrage"];
	$couplefrottement = $_SESSION["couplefrottement"];
	$constantefem = $_SESSION["constantefem"];
	$constantecouple = $_SESSION["constantecouple"];
	$courantdemarrage = $_SESSION["courantdemarrage"];
	$couplerendemementmax = $_SESSION["couplerendemementmax"];

	
	// Parametres du graphique
	$precision = 10;
	//$nbPoints = $coupledemarrage * $precision;
	$nbPoints = ($coupledemarrage * $precision) + 1;
	//$nbPoints = 140;
	$pas = 1;
	
	
	// Calcul de la courbe COURANT
	$coeffDirecteurCourant = ($courantdemarrage - $courantavide) /( $coupledemarrage - 0.0);
	$ordonneeOrigineCourant = $courantavide;
	$courantMax = 0.0;
		
	for($i=0; $i<$nbPoints; $i++)
	{
		$datayCourant[$i] = ($coeffDirecteurCourant * ($i/$precision)) + $ordonneeOrigineCourant;

		if ($datayCourant[$i] > $courantMax)
		{
			$courantMax = $datayCourant[$i];
		}
	}
	
	
	// Calcul de la courbe VITESSE
	$coeffDirecteurVitesse = (0.0 - $vitesseavide) / ($coupledemarrage - 0.0);
	$ordonneeOrigineVitesse = $vitesseavide;
	$vitesseMax = 0.0;
	
	for($i=0; $i<$nbPoints; $i++)
	{
		$datayVitesse[$i] = ($coeffDirecteurVitesse * ($i/$precision)) + $ordonneeOrigineVitesse;

		if ($datayVitesse[$i] > $vitesseMax)
		{
			$vitesseMax = $datayVitesse[$i];
		}
	}
	
	
	// Calcul de la courbe PUISSANCE
	$puissanceMax = 0.0;
	for($i=0; $i<$nbPoints; $i++)
	{
		$datayPuissance[$i] = ($i/$precision) * $datayVitesse[$i] * (3.1415927/30000);

		if ($datayPuissance[$i] > $puissanceMax)
		{
			$puissanceMax = $datayPuissance[$i];
		}
	}
	
	
	// Calcul de la courbe RENDEMENT
	$rendementMax = 0.0;
	for($i=0; $i<$nbPoints; $i++)
	{
		$u = ($resistance * $datayCourant[$i]) + ($constantefem * $datayVitesse[$i] * 0.001);
		$datayRendement[$i] =  ($datayPuissance[$i] / ($u * $datayCourant[$i])) * 100.0;

		if ($datayRendement[$i] > $rendementMax)
		{
			$rendementMax = $datayRendement[$i];
		}
	}
	
	
	
	// Creation du graphique
	$graph = new Graph(640, 480);

	// Configuration du graphique
	$graph->SetMargin(50, 200, 50, 50);	// left, right, top ,bottom
	$graph->SetMarginColor('white');

	$graph->SetScale('intlin', 0, 0);
	$graph->title->Set("Moteur ".$reference." sous ".$_SESSION["tensionnominale"]." V");
	$graph->title->SetFont(FF_VERA);
	$graph->xaxis->title->Set("Couple (mNm x ".$precision.")");
	
	// Calcul pour adapter la hauteur maximum de l'echelle de l'axe des ordonnees
	$vitesseMax = $vitesseMax * 1.1;
	$puissanceMax = $puissanceMax * 1.1;
	$graph->SetYScale(0,'lin', 0, $vitesseMax);
	$graph->SetYScale(1,'lin', 0, $puissanceMax);
	$graph->SetYScale(2,'lin', 0, 100);
	$graph->SetYDeltaDist(70);

	
	// Ajout des courbes au graphique
	$p1 = new LinePlot($datayCourant);
	$graph->yaxis->title->Set('Courant (A)');
	$graph->yaxis->title->SetMargin(5);
	$graph->Add($p1);
		
	$p2 = new LinePlot($datayVitesse);
	$p2->SetColor('teal');
	$graph->AddY(0,$p2);
	$graph->ynaxis[0]->SetColor('teal');
	$graph->ynaxis[0]->SetTitle('Vitesse (rpm)');

	$p3 = new LinePlot($datayPuissance);
	$p3->SetColor('red');
	$graph->AddY(1,$p3);
	$graph->ynaxis[1]->SetColor('red');
	$graph->ynaxis[1]->SetTitle('Puissance (W)');

	$p4 = new LinePlot($datayRendement);
	$p4->SetColor('blue');
	$graph->AddY(2,$p4);
	$graph->ynaxis[2]->SetColor('blue');
	$graph->ynaxis[2]->SetTitle('Rendement (%)');


	// Affichage du graphique
	$graph->Stroke();
?>
